@@ -142,4 +142,8 @@ from .read_indigenous_lands_in_study import read_indigenous_lands_in_study
 from .read_conservation_units import read_conservation_units
 from .read_conservation_units_without_delimitation import read_conservation_units_without_delimitation
 from .read_dup import read_dup
-from .read_2d_seismic import read_2d_seismic
\ No newline at end of file
+from .read_2d_seismic import read_2d_seismic
+from .read_3d_seismic import read_3d_seismic
+from .read_dams_ana import read_dams_ana
+from .read_locks_dnit import read_locks_dnit
+from .read_special_artworks_dnit import read_special_artworks_dnit
