@@ -62,6 +62,7 @@ def list_geobr():
         {"Function": "read_vegetation", "Geography": "Brazilian Vegetation", "Years": "All", "Source": "IBGE"},
         {"Function": "read_transmission_lines_ons", "Geography": "Transmission Lines", "Years": "All", "Source": "ONS"},
         {"Function": "read_water_bodies_ana", "Geography": "Water Bodies", "Years": "All", "Source": "ANA"},
+        {"Function": "read_dams_ana", "Geography": "Dams and Reservoirs", "Years": "All", "Source": "ANA"},
         {"Function": "read_pan_strategic_areas", "Geography": "PAN Strategic Areas", "Years": "All", "Source": "ICMBio"},
         {"Function": "read_geographic_regions", "Geography": "Geographic Regions", "Years": "All", "Source": "IBGE"},
         {"Function": "read_biosphere_reserves", "Geography": "Biosphere Reserves", "Years": "All", "Source": "MMA"},
@@ -94,9 +95,11 @@ def list_geobr():
         {"Function": "read_private_aerodromes", "Geography": "Private Aerodromes", "Years": "All", "Source": "MapBiomas"},
         {"Function": "read_state_highways", "Geography": "State Highways", "Years": "All", "Source": "MapBiomas"},
         {"Function": "read_federal_highways", "Geography": "Federal Highways", "Years": "All", "Source": "MapBiomas"},
-        {"Function": "read_railways", "Geography": "Railways", "Years": "All", "Source": "MapBiomas"},
+        {"Function": "read_railways", "Geography": "Railways", "Years": "All", "Source": "DNIT"},
         {"Function": "read_waterways", "Geography": "Waterways", "Years": "All", "Source": "SNIRH"},
         {"Function": "read_heliports", "Geography": "Heliports", "Years": "All", "Source": "MapBiomas"},
+        {"Function": "read_special_artworks_dnit", "Geography": "Special Artworks (Bridges, Viaducts)", "Years": "All", "Source": "DNIT"},
+        {"Function": "read_locks_dnit", "Geography": "Navigation Locks (Eclusas)", "Years": "All", "Source": "DNIT"},
         
         # Land tenure and property datasets
         {"Function": "read_snci_properties", "Geography": "SNCI Properties", "Years": "All", "Source": "INCRA"},
@@ -148,6 +151,7 @@ def list_geobr():
         {"Function": "read_production_fields", "Geography": "Oil and Gas Production Fields", "Years": "All", "Source": "ANP"},
         {"Function": "read_oil_wells", "Geography": "Oil and Gas Wells", "Years": "All", "Source": "ANP"},
         {"Function": "read_2d_seismic", "Geography": "2D Seismic Surveys", "Years": "All", "Source": "ANP"},
+        {"Function": "read_3d_seismic", "Geography": "3D Seismic Surveys", "Years": "All", "Source": "ANP"},
         {"Function": "read_fuel_bases", "Geography": "Fuel Bases", "Years": "All", "Source": "EPE"},
         {"Function": "read_glp_bases", "Geography": "GLP (LPG) Bases", "Years": "All", "Source": "EPE"},
         {"Function": "read_processing_facilities", "Geography": "Oil and Gas Processing Facilities", "Years": "All", "Source": "EPE"},
